@@ -69,7 +69,7 @@
 #' @importFrom rlang is_empty UQ enexpr enquo expr_text quo_name eval_tidy .data
 #' @export
 #' @importFrom ggplot2 ggplot geom_density facet_wrap aes theme_minimal theme scale_alpha_continuous guides labs geom_segment element_blank
-#' @importFrom tidyr gather replace_na
+#' @importFrom tidyr gather
 #' @importFrom cowplot plot_grid
 #' @importFrom stats quantile
 #' @export
@@ -91,8 +91,7 @@ dagp_plot = function(drawsDF,densityPlot = FALSE) { # case where untidy posterio
     tryCatch({
       drawsDF = drawsDF %>%
       addPriorGroups() %>%
-        mutate(priorGroup = tidyr::replace_na(priorGroup,  ###line to try
-                          999999)) %>%
+        mutate(priorGroup = ifelse(is.na(priorGroup),999999,priorGroup)) %>%
       dplyr::filter(!is.na(priorGroup)) ##if try works, erase this line
     priorGroups = unique(drawsDF$priorGroup)
     numPriorGroups = length(priorGroups)
@@ -118,7 +117,7 @@ dagp_plot = function(drawsDF,densityPlot = FALSE) { # case where untidy posterio
         geom_segment(aes(x = q05, xend = q95, alpha = alphaLevel), size = 4, color = "#5f9ea0") +
         geom_segment(aes(x = q45, xend = q55, alpha = alphaLevel), size = 4, color = "#11114e") +
         scale_alpha_continuous(range = c(0.6,1))  +
-        guides(alpha = FALSE) +
+        guides(alpha = "none") +
         theme_minimal(12) +
         labs(y = element_blank(),
              x = "parameter value",
