@@ -33,7 +33,7 @@ rhsDecompDistr = function(rhs) {
   allArgs = names(formals(fnName)) ##function arguments  ##note this used to use formalArgs, but did not work with beta distribution
 
   ## fill in missing arguments in list
-  for (i in 1:length(allArgs)) {
+  for (i in seq_along(allArgs)) {
     if (!(allArgs[i] %in% namedArgDF$argName)) {
       #arg Name missing
       insertIndex = which(namedArgDF$argName == "")[1]
@@ -368,7 +368,7 @@ findNodeID = function(graphListOrDF, nodeLabel) {
     nodeDF = graphListOrDF$nodes_df
   }
 
-  for (i in 1:length(nodeLabel)) {
+  for (i in seq_along(nodeLabel)) {
     nodeID[i] = as.integer(NA) ## set id to zero meaning unlabelled yet
     # search auto_label column
     nodePosition = max(which(nodeDF$auto_label == nodeLabel[i]), 0)
@@ -447,12 +447,13 @@ pseudoPlate = function(graph) {
   pseudo_plate_node_df = plateNodeDF
 
 
-  ## is any node duplicated
+  ## is any node duplicated (returns index of first duplicate node)
   duplicatePosition = anyDuplicated(plateNodeDF$nodeID)
 
   ## if node appears twice, need to make a virtual cluster
   ## such that each node is a member of a unique subgraph
   ## composed of all of the node's indexes
+
   while (duplicatePosition > 0) {
     duplicatedNodeID = plateNodeDF$nodeID[duplicatePosition]
 
@@ -485,6 +486,10 @@ pseudoPlate = function(graph) {
       dplyr::filter(nodeID != duplicatedNodeID) %>%
       dplyr::bind_rows(data.frame(indexID = newIndex, nodeID = duplicatedNodeID))
 
+    ## update plateDF and plateNodeDF
+    plateNodeDF = pseudo_plate_node_df
+    plateDF = pseudo_plate_index_df
+
     ## condition to break out.
     duplicatePosition = anyDuplicated(pseudo_plate_node_df$nodeID)
   }  #end while loop
